const int red_pin = 11;
const int green_pin = 10;
const int blue_pin = 9;

//Maximum and minimum values
const int max_hot = 30;
const int min_cold = 0;

void setup() {
  Serial.begin(9600);
  
  pinMode(green_pin, OUTPUT);
  pinMode(blue_pin, OUTPUT);
  pinMode(red_pin, OUTPUT);

  setColor(255, 255, 255); //White
}

void loop()
{
  String temperature_string = "";

  if (Serial.available()) 
  {
    
    //This while-loop receives a string from the serial port  
    while (Serial.available()) {
      char c = Serial.read();                        //gets one byte from serial buffer
      temperature_string = temperature_string + c;   //adds the character to the string
      delay(10);                                     //delay to allow buffer to fill 
    }
    
    //Quick blink to indicate that temperature was updated
    digitalWrite(red_pin, HIGH);
    digitalWrite(green_pin, HIGH);
    digitalWrite(blue_pin, HIGH);
    delay(100);
    
    
    //Now temperature_string will contain something like "23". 
    //But since this is text, we need to convert it to an integer
    int temperature = temperature_string.toInt();

    //Now temperature contains the temperature value as an integer
    
    //Cap temperature at max_hot and min_cold
    if (temperature > max_hot)
      temperature = max_hot;
    else if (temperature < min_cold)
      temperature = min_cold;

    //Calculate the middle temperature and "half range"
    int middle_temp = min_cold + (max_hot-min_cold)/2;
    int half_range = (max_hot-min_cold)/2;
    
    
    if (temperature < middle_temp) {
      int r = 0;
      int b = 255 * (middle_temp - temperature) / half_range;
      int g = 255 - 255 * (middle_temp - temperature) / half_range;

      Serial.println(r);
      Serial.println(g);
      Serial.println(b);
      
      setColor(r, g, b);
    }
    else if (temperature > middle_temp) {
      int r = 255 * (temperature - middle_temp) / half_range;
      int b = 0;
      int g = 255 - 255 * (temperature - middle_temp) / half_range;

      Serial.println(r);
      Serial.println(g);
      Serial.println(b);
      
      setColor(r, g, b);
    }
    else {
      setColor(0, 255, 0);
    }
  }
}

void setColor(int red, int green, int blue)
{
  analogWrite(red_pin, 255 - red);
  analogWrite(green_pin, 255 - green);
  analogWrite(blue_pin, 255 - blue);
}
